@@ -63,7 +63,6 @@ typedef struct
 
 struct _CppJavaAssistPriv {
 	AnjutaPreferences *preferences;
-	IAnjutaSymbolManager* isymbol_manager;
 	IAnjutaEditorAssist* iassist;
 	IAnjutaEditorTip* itip;
 
@@ -79,9 +78,9 @@ struct _CppJavaAssistPriv {
 	gint async_calltip_system;
 	gint async_calltip_project;
 
-	GCancellable* cancel_calltip_system;
-	GCancellable* cancel_calltip_file;
-	GCancellable* cancel_calltip_project;
+	IAnjutaSymbolQuery *calltip_query_file;
+	IAnjutaSymbolQuery *calltip_query_system;
+	IAnjutaSymbolQuery *calltip_query_project;
 
 	/* Autocompletion */
 	gboolean member_completion;
@@ -92,10 +91,13 @@ struct _CppJavaAssistPriv {
 	gint async_file_id;
 	gint async_system_id;
 	gint async_project_id;
-	
-	GCancellable* cancel_system;
-	GCancellable* cancel_file;
-	GCancellable* cancel_project;	
+
+	IAnjutaSymbolQuery *ac_query_file;
+	IAnjutaSymbolQuery *ac_query_system;
+	IAnjutaSymbolQuery *ac_query_project;
+
+	/* Member autocompletion */
+	IAnjutaSymbolQuery *query_members;
 };
 
 typedef struct
@@ -119,18 +121,18 @@ cpp_java_assist_proposal_new (IAnjutaSymbol* symbol)
 	IAnjutaSymbolType type = ianjuta_symbol_get_sym_type (symbol, NULL);
 	ProposalData* data = g_new0 (ProposalData, 1);
 
-	data->name = g_strdup (ianjuta_symbol_get_name (symbol, NULL));
+	data->name = g_strdup (ianjuta_symbol_get_string (symbol, IANJUTA_SYMBOL_FIELD_NAME, NULL));
 	switch (type)
 	{
 		case IANJUTA_SYMBOL_TYPE_PROTOTYPE:
 		case IANJUTA_SYMBOL_TYPE_FUNCTION:
 		case IANJUTA_SYMBOL_TYPE_METHOD:
 		case IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG:
-			proposal->label = g_strdup_printf ("%s()", ianjuta_symbol_get_name (symbol, NULL));
+			proposal->label = g_strdup_printf ("%s()", data->name);
 			data->is_func = TRUE;
 			break;
 		default:
-			proposal->label = g_strdup (ianjuta_symbol_get_name (symbol, NULL));
+			proposal->label = g_strdup (data->name);
 			data->is_func = FALSE;
 	}
 	proposal->data = data;
@@ -173,8 +175,6 @@ anjuta_proposal_completion_func (gpointer data)
 /**
  * cpp_java_assist_create_completion_from_symbols:
  * @symbols: Symbol iteration
- * @local_only: Only include symbols with local file scope, useful for
- *  concatination of file and project/global search to avoid duplicates
  * 
  * Create a list of IAnjutaEditorAssistProposals from a list of symbols
  *
@@ -182,7 +182,7 @@ anjuta_proposal_completion_func (gpointer data)
  * with cpp_java_assist_proposal_free()
  */
 static GList*
-cpp_java_assist_create_completion_from_symbols (IAnjutaIterable* symbols, gboolean local_only)
+cpp_java_assist_create_completion_from_symbols (IAnjutaIterable* symbols)
 {
 	GList* list = NULL;
 
@@ -191,11 +191,6 @@ cpp_java_assist_create_completion_from_symbols (IAnjutaIterable* symbols, gboole
 	do
 	{
 		IAnjutaSymbol* symbol = IANJUTA_SYMBOL (symbols);
-		if (local_only)
-		{
-			if (!ianjuta_symbol_is_local (symbol, NULL))
-				continue;
-		}
 		IAnjutaEditorAssistProposal* proposal = cpp_java_assist_proposal_new (symbol);	
 
 		list = g_list_append (list, proposal);
@@ -481,7 +476,24 @@ cpp_java_assist_create_completion_cache (CppJavaAssist* assist)
 }
 
 /**
- * cpp_java_assist_clear_completion_cache
+ * cpp_java_assist_cancel_queries:
+ * @assist: self
+ *
+ * Abort all async operations
+ */
+static void
+cpp_java_assist_cancel_queries (CppJavaAssist* assist)
+{
+	ianjuta_symbol_query_cancel (assist->priv->ac_query_file, NULL);
+	ianjuta_symbol_query_cancel (assist->priv->ac_query_project, NULL);
+	ianjuta_symbol_query_cancel (assist->priv->ac_query_system, NULL);
+	assist->priv->async_file_id = 0;
+	assist->priv->async_project_id = 0;
+	assist->priv->async_system_id = 0;
+}
+
+/**
+ * cpp_java_assist_clear_completion_cache:
  * @assist: self
  *
  * Clear the completion cache, aborting all async operations
@@ -489,15 +501,15 @@ cpp_java_assist_create_completion_cache (CppJavaAssist* assist)
 static void
 cpp_java_assist_clear_completion_cache (CppJavaAssist* assist)
 {
-	g_cancellable_cancel (assist->priv->cancel_file);
-	g_cancellable_cancel (assist->priv->cancel_project);	
-	g_cancellable_cancel (assist->priv->cancel_system);
+	cpp_java_assist_cancel_queries (assist);
 	if (assist->priv->completion_cache)
 	{	
 		g_list_foreach (assist->priv->completion_cache->items, (GFunc) cpp_java_assist_proposal_free, NULL);
 		g_completion_free (assist->priv->completion_cache);
 	}
 	assist->priv->completion_cache = NULL;
+	assist->priv->member_completion = FALSE;
+	assist->priv->autocompletion = FALSE;
 }
 
 /**
@@ -555,17 +567,13 @@ cpp_java_assist_create_member_completion_cache (CppJavaAssist* assist, IAnjutaIt
 		gint retval = FALSE;
 		/* Query symbol children */
 		IAnjutaIterable *children = 
-			ianjuta_symbol_manager_get_members (assist->priv->isymbol_manager,
+			ianjuta_symbol_query_search_members (assist->priv->query_members,
 			                                    IANJUTA_SYMBOL(symbol),
-			                                    IANJUTA_SYMBOL_FIELD_SIMPLE |
-			                                    IANJUTA_SYMBOL_FIELD_KIND |
-			                                    IANJUTA_SYMBOL_FIELD_ACCESS |
-			                                    IANJUTA_SYMBOL_FIELD_TYPE,
 			                                    NULL);
 		if (children)
 		{
 			GList* proposals = 
-				cpp_java_assist_create_completion_from_symbols (children, FALSE);
+				cpp_java_assist_create_completion_from_symbols (children);
 			cpp_java_assist_create_completion_cache (assist);
 			g_completion_add_items (assist->priv->completion_cache, proposals);
 
@@ -593,23 +601,17 @@ cpp_java_assist_create_member_completion_cache (CppJavaAssist* assist, IAnjutaIt
  * Called by the async search method when it found symbols
  */
 static void
-on_symbol_search_complete (gint search_id, IAnjutaIterable* symbols, CppJavaAssist* assist)
+on_symbol_search_complete (IAnjutaSymbolQuery *query, IAnjutaIterable* symbols,
+						   CppJavaAssist* assist)
 {
 	GList* proposals;
-	if (search_id == assist->priv->async_file_id)
-	{
-		proposals = cpp_java_assist_create_completion_from_symbols (symbols, TRUE);
-	}
-	else
-	{
-		proposals = cpp_java_assist_create_completion_from_symbols (symbols, FALSE);
-	}
+	proposals = cpp_java_assist_create_completion_from_symbols (symbols);
 
-	if (search_id == assist->priv->async_file_id)
+	if (query == assist->priv->ac_query_file)
 		assist->priv->async_file_id = 0;
-	else if (search_id == assist->priv->async_project_id)
+	else if (query == assist->priv->ac_query_project)
 		assist->priv->async_project_id = 0;
-	else if (search_id == assist->priv->async_system_id)
+	else if (query == assist->priv->ac_query_system)
 		assist->priv->async_system_id = 0;
 	else
 		g_assert_not_reached ();
@@ -617,11 +619,9 @@ on_symbol_search_complete (gint search_id, IAnjutaIterable* symbols, CppJavaAssi
 	g_completion_add_items (assist->priv->completion_cache, proposals);
 	gboolean running = assist->priv->async_system_id || assist->priv->async_file_id ||
 		assist->priv->async_project_id;
-	
-	cpp_java_assist_populate_real (assist, !running);
+	if (!running)
+		cpp_java_assist_populate_real (assist, TRUE);
 	g_list_free (proposals);
-	if (symbols)
-		g_object_unref (symbols);
 }
 
 /**
@@ -648,11 +648,6 @@ cpp_java_assist_create_autocompletion_cache (CppJavaAssist* assist, IAnjutaItera
 	else
 	{
 		gchar *pattern = g_strconcat (pre_word, "%", NULL);
-		IAnjutaSymbolType match_types = IANJUTA_SYMBOL_TYPE_MAX;
-		IAnjutaSymbolField fields = IANJUTA_SYMBOL_FIELD_SIMPLE |
-			IANJUTA_SYMBOL_FIELD_TYPE |
-			IANJUTA_SYMBOL_FIELD_ACCESS |
-			IANJUTA_SYMBOL_FIELD_KIND;
 		
 		cpp_java_assist_create_completion_cache (assist);
 		cpp_java_assist_update_pre_word (assist, pre_word);
@@ -662,48 +657,17 @@ cpp_java_assist_create_autocompletion_cache (CppJavaAssist* assist, IAnjutaItera
 			GFile *file = ianjuta_file_get_file (IANJUTA_FILE (assist->priv->iassist), NULL);
 			if (file != NULL)
 			{
-				g_cancellable_reset (assist->priv->cancel_file);
-				assist->priv->async_file_id =
-					ianjuta_symbol_manager_search_file_async (assist->priv->isymbol_manager,
-					                                          match_types,
-					                                          TRUE,
-					                                          fields,
-					                                          pattern, file, -1, -1, 
-					                                          assist->priv->cancel_file,
-					                                          NULL, 
-					                                          (IAnjutaSymbolManagerSearchCallback) on_symbol_search_complete,
-					                                          assist,
-					                                          NULL);
+				assist->priv->async_file_id = 1;
+				ianjuta_symbol_query_search_file (assist->priv->ac_query_file,
+												  pattern, file, NULL);
 				g_object_unref (file);
 			}
 		}
 		/* This will avoid duplicates of FUNCTION and PROTOTYPE */
-		match_types &= ~IANJUTA_SYMBOL_TYPE_FUNCTION;
-		g_cancellable_reset (assist->priv->cancel_project);
-		assist->priv->async_project_id =
-			ianjuta_symbol_manager_search_project_async (assist->priv->isymbol_manager,
-			                                             match_types,
-			                                             TRUE,
-			                                             fields,
-			                                             pattern, 
-			                                             IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1, 
-			                                             assist->priv->cancel_project,
-			                                             NULL, 
-			                                             (IAnjutaSymbolManagerSearchCallback) on_symbol_search_complete, 
-			                                             assist,
-			                                             NULL);
-		g_cancellable_reset (assist->priv->cancel_system);
-		assist->priv->async_system_id = 
-			ianjuta_symbol_manager_search_system_async (assist->priv->isymbol_manager,
-			                                            match_types,
-			                                            TRUE,
-			                                            fields,
-			                                            pattern, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1,
-			                                            assist->priv->cancel_system,
-			                                            NULL, 
-			                                            (IAnjutaSymbolManagerSearchCallback) on_symbol_search_complete, 
-			                                            assist,
-			                                            NULL);
+		assist->priv->async_project_id = 1;
+		ianjuta_symbol_query_search (assist->priv->ac_query_project, pattern, NULL);
+		assist->priv->async_system_id = 1;
+		ianjuta_symbol_query_search (assist->priv->ac_query_system, pattern, NULL);
 		g_free (pre_word);
 		g_free (pattern);
 
@@ -732,11 +696,11 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter, GList* merge)
 		do
 		{
 			IAnjutaSymbol* symbol = IANJUTA_SYMBOL(iter);
-			const gchar* name = ianjuta_symbol_get_name(symbol, NULL);
+			const gchar* name = ianjuta_symbol_get_string (symbol, IANJUTA_SYMBOL_FIELD_NAME, NULL);
 			if (name != NULL)
 			{
-				const gchar* args = ianjuta_symbol_get_args(symbol, NULL);
-				const gchar* rettype = ianjuta_symbol_get_returntype (symbol, NULL);
+				const gchar* args = ianjuta_symbol_get_string (symbol, IANJUTA_SYMBOL_FIELD_SIGNATURE, NULL);
+				const gchar* rettype = ianjuta_symbol_get_string (symbol, IANJUTA_SYMBOL_FIELD_RETURNTYPE, NULL);
 				gchar* print_args;
 				gchar* separator;
 				gchar* white_name;
@@ -786,14 +750,15 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter, GList* merge)
  * Called by the async search method when it found calltips
  */
 static void
-on_calltip_search_complete (gint search_id, IAnjutaIterable* symbols, CppJavaAssist* assist)
+on_calltip_search_complete (IAnjutaSymbolQuery *query, IAnjutaIterable* symbols,
+							CppJavaAssist* assist)
 {
 	assist->priv->tips = cpp_java_assist_create_calltips (symbols, assist->priv->tips);
-	if (search_id == assist->priv->async_calltip_file)
+	if (query == assist->priv->calltip_query_file)
 		assist->priv->async_calltip_file = 0;
-	else if (search_id == assist->priv->async_calltip_project)
+	else if (query == assist->priv->calltip_query_project)
 		assist->priv->async_calltip_project = 0;
-	else if (search_id == assist->priv->async_calltip_system)
+	else if (query == assist->priv->calltip_query_system)
 		assist->priv->async_calltip_system = 0;
 	else
 		g_assert_not_reached ();
@@ -808,8 +773,6 @@ on_calltip_search_complete (gint search_id, IAnjutaIterable* symbols, CppJavaAss
 		                         assist->priv->calltip_iter,
 		                         NULL);
 	}
-	if (symbols)
-		g_object_unref (symbols);
 }
 
 /**
@@ -823,17 +786,6 @@ static void
 cpp_java_assist_query_calltip (CppJavaAssist *assist, const gchar *call_context)
 {	
 	CppJavaAssistPriv* priv = assist->priv;
-	IAnjutaSymbolType types = 
-		IANJUTA_SYMBOL_TYPE_PROTOTYPE |
-		IANJUTA_SYMBOL_TYPE_FUNCTION |
-		IANJUTA_SYMBOL_TYPE_METHOD |
-		IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG;
-	IAnjutaSymbolField fields = 
-		IANJUTA_SYMBOL_FIELD_SIMPLE |
-		IANJUTA_SYMBOL_FIELD_TYPE |
-		IANJUTA_SYMBOL_FIELD_ACCESS |
-		IANJUTA_SYMBOL_FIELD_KIND;
-
 	
 	/* Search file */
 	if (IANJUTA_IS_FILE (assist->priv->itip))
@@ -842,52 +794,23 @@ cpp_java_assist_query_calltip (CppJavaAssist *assist, const gchar *call_context)
 
 		if (file != NULL)
 		{
-			g_cancellable_reset (assist->priv->cancel_calltip_file);
-			priv->async_calltip_file = 
-				ianjuta_symbol_manager_search_file_async (assist->priv->isymbol_manager,
-				                                          types,
-				                                          TRUE, 
-				                                          fields,
-				                                          call_context, file, -1, -1,
-				                                          assist->priv->cancel_calltip_file,
-				                                          NULL,
-				                                          (IAnjutaSymbolManagerSearchCallback) on_calltip_search_complete,
-				                                          assist,
+			priv->async_calltip_file = 1;
+			ianjuta_symbol_query_search_file (assist->priv->calltip_query_file,
+				                                          call_context, file,
 				                                          NULL);
 			g_object_unref (file);
 		}
 	}
 
-	types &= ~IANJUTA_SYMBOL_TYPE_FUNCTION;
 	/* Search Project */
-	g_cancellable_reset (assist->priv->cancel_calltip_file);
-	priv->async_calltip_project = 
-		ianjuta_symbol_manager_search_project_async (assist->priv->isymbol_manager,
-		                                             types,
-		                                             TRUE, 
-		                                             fields,
-		                                             call_context, 
-		                                             IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1,
-		                                             assist->priv->cancel_calltip_project,
-		                                             NULL,
-		                                             (IAnjutaSymbolManagerSearchCallback) on_calltip_search_complete,
-		                                             assist,
-		                                             NULL);
+	priv->async_calltip_project = 1;
+	ianjuta_symbol_query_search (assist->priv->calltip_query_project,
+		                                             call_context, NULL);
 	
 	/* Search system */
-	g_cancellable_reset (assist->priv->cancel_calltip_file);
-	assist->priv->async_calltip_system = 
-		ianjuta_symbol_manager_search_system_async (assist->priv->isymbol_manager,
-		                                            types,
-		                                            TRUE, 
-		                                            fields,
-		                                            call_context, 
-		                                            IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1,
-		                                            assist->priv->cancel_calltip_system,
-		                                            NULL,
-		                                            (IAnjutaSymbolManagerSearchCallback) on_calltip_search_complete,
-		                                            assist,
-		                                            NULL);
+	assist->priv->async_calltip_system = 1;
+	ianjuta_symbol_query_search (assist->priv->calltip_query_system,
+		                                            call_context, NULL);
 }
 
 /**
@@ -1041,9 +964,13 @@ cpp_java_assist_create_calltip_context (CppJavaAssist* assist,
 static void
 cpp_java_assist_clear_calltip_context (CppJavaAssist* assist)
 {
-	g_cancellable_cancel (assist->priv->cancel_calltip_file);
-	g_cancellable_cancel (assist->priv->cancel_calltip_project);
-	g_cancellable_cancel (assist->priv->cancel_calltip_system);
+	ianjuta_symbol_query_cancel (assist->priv->calltip_query_file, NULL);
+	ianjuta_symbol_query_cancel (assist->priv->calltip_query_project, NULL);
+	ianjuta_symbol_query_cancel (assist->priv->calltip_query_system, NULL);
+
+	assist->priv->async_calltip_file = 0;
+	assist->priv->async_calltip_project = 0;
+	assist->priv->async_calltip_system = 0;
 	
 	g_free (assist->priv->calltip_context);
 	assist->priv->calltip_context = NULL;
@@ -1120,6 +1047,20 @@ cpp_java_assist_calltip (CppJavaAssist *assist)
 	g_object_unref (iter);
 	return FALSE;
 }
+
+/**
+ * cpp_java_assist_cancelled:
+ * @iassist: IAnjutaEditorAssist that emitted the signal
+ * @assist: CppJavaAssist object
+ *
+ * Stop any autocompletion queries when the cancelled signal was received
+ */
+static void
+cpp_java_assist_cancelled (IAnjutaEditorAssist* iassist, CppJavaAssist* assist)
+{
+	cpp_java_assist_cancel_queries (assist);
+}
+
 /**
  * cpp_java_assist_none:
  * @self: IAnjutaProvider object
@@ -1193,14 +1134,13 @@ cpp_java_assist_populate (IAnjutaProvider* self, IAnjutaIterable* cursor, GError
 			cpp_java_assist_populate_real (assist, TRUE);
 			g_free (pre_word);
 			return;
-		}
-		else
-			cpp_java_assist_clear_completion_cache (assist);
+		}			
 		g_free (pre_word);
 	}
+
+	cpp_java_assist_clear_completion_cache (assist);
+	
 	/* Check for member completion */
-	assist->priv->member_completion = FALSE;
-	assist->priv->autocompletion = FALSE;
 	if (cpp_java_assist_create_member_completion_cache (assist, cursor))
 	{
 		assist->priv->member_completion = TRUE;
@@ -1220,6 +1160,34 @@ cpp_java_assist_populate (IAnjutaProvider* self, IAnjutaIterable* cursor, GError
 	cpp_java_assist_none (self, assist);
 } 
 
+/**
+ * cpp_java_assist_find_next_brace:
+ * @self: CppJavaAssist object
+ * @iter: Iter to start searching at
+ *
+ * Returns: TRUE if the next non-whitespace character is a opening brace,
+ * FALSE otherwise
+ */
+static gboolean
+cpp_java_assist_find_next_brace (CppJavaAssist* assist,
+                                 IAnjutaIterable* iter)
+{
+	IAnjutaIterable* my_iter = ianjuta_iterable_clone (iter, NULL);
+	char ch;
+	do
+	{
+		ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (my_iter), 0, NULL);
+		if (ch == '(')
+		{
+			g_object_unref (my_iter);
+		    return TRUE;
+		}
+	}
+	while (g_ascii_isspace (ch) && ianjuta_iterable_next (my_iter, NULL));
+	
+	return FALSE;
+}
+
 /**
  * cpp_java_assist_activate:
  * @self: IAnjutaProvider object
@@ -1253,11 +1221,13 @@ cpp_java_assist_activate (IAnjutaProvider* self, IAnjutaIterable* iter, gpointer
 			anjuta_preferences_get_bool_with_default (assist->priv->preferences,
 													 PREF_AUTOCOMPLETE_BRACE_AFTER_FUNC,
 													 TRUE);
-		if (add_space_after_func)
-			g_string_append (assistance, " ");
-		
-		if (add_brace_after_func)
-			g_string_append (assistance, "(");
+		if (!cpp_java_assist_find_next_brace (assist, iter))
+		{
+			if (add_space_after_func)
+				g_string_append (assistance, " ");
+			if (add_brace_after_func)
+				g_string_append (assistance, "(");
+		}
 	}
 	
 	te = IANJUTA_EDITOR (assist->priv->iassist);
@@ -1287,7 +1257,7 @@ cpp_java_assist_activate (IAnjutaProvider* self, IAnjutaIterable* iter, gpointer
 		                                              TRUE))	
 			assist->priv->calltip_active = cpp_java_assist_calltip (assist);
 
-	}	
+	}
 	g_string_free (assistance, TRUE);
 }
 
@@ -1334,6 +1304,7 @@ cpp_java_assist_install (CppJavaAssist *assist, IAnjutaEditor *ieditor)
 	{
 		assist->priv->iassist = IANJUTA_EDITOR_ASSIST (ieditor);
 		ianjuta_editor_assist_add (IANJUTA_EDITOR_ASSIST (ieditor), IANJUTA_PROVIDER(assist), NULL);
+		g_signal_connect (ieditor, "cancelled", G_CALLBACK (cpp_java_assist_cancelled), assist);
 	}
 	else
 	{
@@ -1361,7 +1332,9 @@ static void
 cpp_java_assist_uninstall (CppJavaAssist *assist)
 {
 	g_return_if_fail (assist->priv->iassist != NULL);
-
+	
+	g_signal_handlers_disconnect_by_func (assist->priv->iassist,
+	                                      cpp_java_assist_cancelled, assist);
 	ianjuta_editor_assist_remove (assist->priv->iassist, IANJUTA_PROVIDER(assist), NULL);
 	assist->priv->iassist = NULL;
 }
@@ -1370,12 +1343,6 @@ static void
 cpp_java_assist_init (CppJavaAssist *assist)
 {
 	assist->priv = g_new0 (CppJavaAssistPriv, 1);
-	assist->priv->cancel_calltip_file = g_cancellable_new();
-	assist->priv->cancel_calltip_project = g_cancellable_new();
-	assist->priv->cancel_calltip_system = g_cancellable_new();
-	assist->priv->cancel_file = g_cancellable_new();
-	assist->priv->cancel_project = g_cancellable_new();
-	assist->priv->cancel_system = g_cancellable_new();
 }
 
 static void
@@ -1385,12 +1352,6 @@ cpp_java_assist_finalize (GObject *object)
 	cpp_java_assist_uninstall (assist);
 	cpp_java_assist_clear_completion_cache (assist);
 	cpp_java_assist_clear_calltip_context (assist);
-	g_object_unref (assist->priv->cancel_calltip_file);
-	g_object_unref (assist->priv->cancel_calltip_project);
-	g_object_unref (assist->priv->cancel_calltip_system);
-	g_object_unref (assist->priv->cancel_file);
-	g_object_unref (assist->priv->cancel_project);
-	g_object_unref (assist->priv->cancel_system);		
 	g_free (assist->priv);
 	G_OBJECT_CLASS (cpp_java_assist_parent_class)->finalize (object);
 }
@@ -1409,15 +1370,154 @@ cpp_java_assist_new (IAnjutaEditor *ieditor,
 					 AnjutaPreferences *prefs)
 {
 	CppJavaAssist *assist;
-	
+	static IAnjutaSymbolField calltip_fields[] = {
+		IANJUTA_SYMBOL_FIELD_ID,
+		IANJUTA_SYMBOL_FIELD_NAME,
+		IANJUTA_SYMBOL_FIELD_RETURNTYPE,
+		IANJUTA_SYMBOL_FIELD_SIGNATURE
+	};
+	static IAnjutaSymbolField ac_fields[] = {
+		IANJUTA_SYMBOL_FIELD_ID,
+		IANJUTA_SYMBOL_FIELD_NAME,
+		IANJUTA_SYMBOL_FIELD_KIND,
+		IANJUTA_SYMBOL_FIELD_TYPE,
+		IANJUTA_SYMBOL_FIELD_ACCESS
+	};
+
 	if (!IANJUTA_IS_EDITOR_ASSIST (ieditor) && !IANJUTA_IS_EDITOR_TIP (ieditor))
 	{
 		/* No assistance is available with the current editor */
 		return NULL;
 	}
 	assist = g_object_new (TYPE_CPP_JAVA_ASSIST, NULL);
-	assist->priv->isymbol_manager = isymbol_manager;
 	assist->priv->preferences = prefs;
+
+	/* Create call tip queries */
+	/* Calltip in file */
+	assist->priv->calltip_query_file =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH_FILE,
+		                                     IANJUTA_SYMBOL_QUERY_DB_PROJECT,
+		                                     NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->calltip_query_file,
+	                                 G_N_ELEMENTS (calltip_fields),
+	                                 calltip_fields, NULL);
+	ianjuta_symbol_query_set_filters (assist->priv->calltip_query_file,
+	                                  IANJUTA_SYMBOL_TYPE_PROTOTYPE |
+	                                  IANJUTA_SYMBOL_TYPE_FUNCTION |
+	                                  IANJUTA_SYMBOL_TYPE_METHOD |
+	                                  IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
+	                                  TRUE, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->calltip_query_file,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PRIVATE, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->calltip_query_file,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->calltip_query_file, "async-result",
+	                  G_CALLBACK (on_calltip_search_complete), assist);
+	/* Calltip in project */
+	assist->priv->calltip_query_project =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH,
+		                                     IANJUTA_SYMBOL_QUERY_DB_PROJECT,
+		                                     NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->calltip_query_project,
+	                                 G_N_ELEMENTS (calltip_fields),
+	                                 calltip_fields, NULL);
+	ianjuta_symbol_query_set_filters (assist->priv->calltip_query_project,
+	                                  IANJUTA_SYMBOL_TYPE_PROTOTYPE |
+	                                  IANJUTA_SYMBOL_TYPE_METHOD |
+	                                  IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
+	                                  TRUE, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->calltip_query_project,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PUBLIC, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->calltip_query_project,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->calltip_query_project, "async-result",
+	                  G_CALLBACK (on_calltip_search_complete), assist);
+	/* Calltip in system */
+	assist->priv->calltip_query_system =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH,
+		                                     IANJUTA_SYMBOL_QUERY_DB_SYSTEM,
+		                                     NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->calltip_query_system,
+	                                 G_N_ELEMENTS (calltip_fields),
+	                                 calltip_fields, NULL);
+	ianjuta_symbol_query_set_filters (assist->priv->calltip_query_system,
+	                                  IANJUTA_SYMBOL_TYPE_PROTOTYPE |
+	                                  IANJUTA_SYMBOL_TYPE_METHOD |
+	                                  IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
+	                                  TRUE, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->calltip_query_system,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PUBLIC, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->calltip_query_system,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->calltip_query_system, "async-result",
+	                  G_CALLBACK (on_calltip_search_complete), assist);
+
+	/* Create autocomplete queries */
+	/* AC in file */
+	assist->priv->ac_query_file =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH_FILE,
+		                                     IANJUTA_SYMBOL_QUERY_DB_PROJECT,
+		                                     NULL);
+	ianjuta_symbol_query_set_group_by (assist->priv->ac_query_file,
+	                                   IANJUTA_SYMBOL_FIELD_NAME, NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->ac_query_file,
+	                                 G_N_ELEMENTS (ac_fields),
+	                                 ac_fields, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->ac_query_file,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PRIVATE, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->ac_query_file,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->ac_query_file, "async-result",
+	                  G_CALLBACK (on_symbol_search_complete), assist);
+	/* AC in project */
+	assist->priv->ac_query_project =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH,
+		                                     IANJUTA_SYMBOL_QUERY_DB_PROJECT,
+		                                     NULL);
+	ianjuta_symbol_query_set_group_by (assist->priv->ac_query_project,
+	                                   IANJUTA_SYMBOL_FIELD_NAME, NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->ac_query_project,
+	                                 G_N_ELEMENTS (ac_fields),
+	                                 ac_fields, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->ac_query_project,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PUBLIC, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->ac_query_project,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->ac_query_project, "async-result",
+	                  G_CALLBACK (on_symbol_search_complete), assist);
+	/* AC in system */
+	assist->priv->ac_query_system =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH,
+		                                     IANJUTA_SYMBOL_QUERY_DB_SYSTEM,
+		                                     NULL);
+	ianjuta_symbol_query_set_group_by (assist->priv->ac_query_system,
+	                                   IANJUTA_SYMBOL_FIELD_NAME, NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->ac_query_system,
+	                                 G_N_ELEMENTS (ac_fields),
+	                                 ac_fields, NULL);
+	ianjuta_symbol_query_set_file_scope (assist->priv->ac_query_system,
+	                                     IANJUTA_SYMBOL_QUERY_SEARCH_FS_PUBLIC, NULL);
+	ianjuta_symbol_query_set_mode (assist->priv->ac_query_system,
+	                               IANJUTA_SYMBOL_QUERY_MODE_ASYNC, NULL);
+	g_signal_connect (assist->priv->ac_query_system, "async-result",
+	                  G_CALLBACK (on_symbol_search_complete), assist);
+
+	/* Members autocompletion */
+	assist->priv->query_members =
+		ianjuta_symbol_manager_create_query (isymbol_manager,
+		                                     IANJUTA_SYMBOL_QUERY_SEARCH_MEMBERS,
+		                                     IANJUTA_SYMBOL_QUERY_DB_PROJECT,
+		                                     NULL);
+	ianjuta_symbol_query_set_fields (assist->priv->query_members,
+	                                 G_N_ELEMENTS (ac_fields),
+	                                 ac_fields, NULL);
+	/* Install support */
 	cpp_java_assist_install (assist, ieditor);
 
 	engine_parser_init (isymbol_manager);	
